close all
clear all
clc

% Making initial mooring line (lying on the bottom) to be stretched into its final shape


g = 9.81;
rhoWater = 1025;
depth = 150;

% Top angle
phi = 49.1*pi/180;

% Top tension (force)
T = 20*g*10^3; % [N]
Ty = T*cos(phi);
Tz = T*sin(phi);


% Defining mooring line properties

% Chain
Lchain = 1000;
Dchain = sqrt(2)*0.088;
EAchain = 6.94*10^4*g*10^3;
wChain = 147; % [kg/m] (weight in water)
MBLchain = 718.8*g*10^3;
Achain = pi/4*Dchain^2;
yieldChain = MBLchain/Achain;
Echain = EAchain/Achain;
rhoChain = (wChain+(Achain*rhoWater))/Achain;

geoChain = 10;
matChain = 10;

% Fibre (polyester)
Lfibre = 100;
Dfibre = 0.16;
EAfibre = 2.40*10^4*g*10^3;
wFibre = 4; % [kg/m] (weight in water)
MBLfibre = 828*g*10^3;
Afibre = pi/4*Dfibre^2;
yieldFibre = MBLfibre/Afibre;
Efibre = EAfibre/Afibre;
rhoFibre = (wFibre+(Afibre*rhoWater))/Afibre;

geoFibre = 20;
matFibre = 20;

%----------Writing mooring line to file----------

Ltot = Lchain+Lfibre;

% Step size (length of beams)
Lstep = 5;

% Number of beams to split mooring line into
nBeams = Ltot/Lstep;

FID = fopen('premodelmooring.fem','w');

fprintf(FID,'HEAD         Mooring line premodel\n');
fprintf(FID,'             Test file\n');
fprintf(FID,'             PTB and PAF\n\n');

%------NODES----------
startNODE = 10000;
NODE = [];
for i=1:(nBeams+1)
    NODE(i,1)=i+startNODE; % Node number
    NODE(i,2)=0; % x-coord
    NODE(i,3)=(i-1)*Lstep; % y-coord
    NODE(i,4)=-depth; % z-coord
end

fprintf(FID,'NODE %i %.3f %.3f %.3f   1 1 1 0 0 0\n',NODE(1,1),NODE(1,2),NODE(1,3),NODE(1,4));
for i=2:(nBeams+1)
    fprintf(FID,'NODE %i %.3f %.3f %.3f\n',NODE(i,1),NODE(i,2),NODE(i,3),NODE(i,4));
end

%-----Spring to ground---------
materialS2G = 30;
startS2G = startNODE+1000;
for i=1:(nBeams+1)
    fprintf(FID,'SPRNG2GR %i %i %i\n', i+startS2G,NODE(i,1),materialS2G);
end

%------Beams-----------
nChain = Lchain/Lstep;
nFibre = Lfibre/Lstep;

beamcounter = 10000;

% Chain
for i=1:nChain
    fprintf(FID,'BEAM %i %i %i %i %i\n',beamcounter,i+startNODE,i+1+startNODE,matChain,geoChain);
    beamcounter = beamcounter+1;
end

%Fibre
for i=1+nChain:nBeams
    fprintf(FID,'BEAM %i %i %i %i %i\n',beamcounter,i+startNODE,i+1+startNODE,matFibre,geoFibre);
    beamcounter = beamcounter+1;
end

% Material data

% Chain
fprintf(FID,'\n\n''            MatID    E-mod    poiss    yield    density\n');
fprintf(FID,'MISOIEP %10d %6u %6.1f %6u %6d\r\n', matChain,Echain,0.3,yieldChain,rhoChain);

fprintf(FID,'\n\n''            GeoID    Do      Thick\n');
fprintf(FID,'PIPE %13d %6.3f %8.3f\r\n', geoChain,Dchain,Dchain/2-0.001);

% Fibre
fprintf(FID,'\n\n''            MatID    E-mod    poiss    yield    density\n');
fprintf(FID,'MISOIEP %10d %6u %6.1f %6u %6d\r\n', matFibre,Efibre,0.3,yieldFibre,rhoFibre);

fprintf(FID,'\n\n''            GeoID    Do      Thick\n');
fprintf(FID,'PIPE %13d %6.2f %8.3f\r\n', geoFibre,Dfibre,Dfibre/2-0.001);

% Spring to ground
fprintf(FID,'\n\n''            MatID    Typ      SprTyp    Coeff    Stf    DofCod    DofCod\n');
fprintf(FID,'MATERIAL %9d    FRIC      comp %8.2f %10u %6d %6d \r\n', materialS2G,0.15,1E+4,12,3);

% Loads

fprintf(FID,'\n\n''            LCase    aX    aY    aZ\n');
fprintf(FID,'GRAVITY        1       0     0   -9.81\n');

fprintf(FID,'\n\n''            LCase    NodeID        Fx        Fy        Fz\n');
fprintf(FID,'NODELOAD      1 %12d %10.2f %10.2f %10.2f\r\n', NODE(nBeams+1),0,Ty,Tz);


fclose(FID);


