function [bctthick,ccmidthick,obtthick,mcmidthick,scmidthick,tofmidthick,bofmidthick,rbmidthick,tfmidthick,scmidthickextra] = thickness(strucdens)

%   Function calculates unknown thicknesses bases on geometry and total
%   mass taken from structural drawings. Stiffeners and other internal
%   detailes is smeared over thickness.

dens = strucdens; % [kg/m3]

%   Buoyancy center tank
bctoutdia = 17; % [m]
bctlen = 7; % [m]
bctmass = 397228.95; % [kg]
bctinrad = sqrt((bctoutdia/2)^2-(bctmass/(pi*bctlen*dens))); % [m]
bctthick = (bctoutdia/2)-bctinrad; % [m]

%   Center column
ccoutdiatop = 3.58; % [m]
ccoutdiabot = 3.56; % [m]
cctopthick = 0.04; % [m]
cctoplen = 37/10; % [m]
cctopmass = masscalc(ccoutdiatop,cctopthick,cctoplen); % [kg]
ccrestmass = masscalc(ccoutdiabot,0.03,31.8)+masscalc(ccoutdiatop,0.04,5)+5300-cctopmass; % [kg]
ccrestlen = 37-cctoplen; % [m]
ccmidthick = (ccoutdiabot-(ccoutdiabot^2-(ccrestmass*4/(pi*ccrestlen*dens)))^0.5)/2;


%   Outer ballast tank
syms t
r1 = 12/2; % [m]
r2 = 3.5/2; % [m]
r3(t) = r1-t; % [m]
r4(t) = r2-t; % [m]
h1 = 7; % [m]
h2 = 6; % [m]
v1 = pi*(r1^2-r3^2)*h1; % [m3]
v2 = (1/3)*pi*(r1^2+(r1*r2)+r2^2)*h2; % [m3]
v3 = (1/3)*pi*(r3^2+(r3*r4)+r4^2)*h2; % [m3]
vtot = v1+v2-v3; % [m3]
mass = 199393.56; % [kg]
eqn = vtot*dens == mass; % [kg]
solt = vpasolve(eqn,t);
obtthick = solt(1);

%   Main columns
mcoutdiatop = 3.58; % [m]
mcoutdiamid = 3.56; % [m]
mcbtthick = 0.04; % [m]
mcbtlen = 33/10; % [m]
mcovpontlen = 3; % [m]
mcbtmass = masscalc(mcoutdiatop,mcbtthick,mcbtlen)*2; % [kg]
mcovpontmass = masscalc(mcoutdiatop,mcbtthick,mcovpontlen); % [kg]
mcrestmass = masscalc(3.58,0.04,5.18+7)+masscalc(3.56,0.03,12+10)+masscalc(3.57,0.033,3)+(883+883+442+1325)-(mcbtmass)-mcovpontmass; % [kg]
mcrestlen = 33-(2*mcbtlen); % [m]
mcmidthick = (mcoutdiamid-(mcoutdiamid^2-(mcrestmass*4/(pi*mcrestlen*dens)))^0.5)/2;


%   Secondary columns
scoutdiatop = 2.83; % [m]
scoutdiamid = 2.80; % [m]
scbtthick = 0.04; % [m]
scbtlen = 33/10; % [m]
scbtmass = masscalc(scoutdiatop,scbtthick,scbtlen)*2; % [kg]
screstmass = masscalc(scoutdiatop,0.023,25)+masscalc(scoutdiatop,0.04,5.18+5.05)+(333+333+2668)-(scbtmass); % [kg]
screstlen = 33-(2*scbtlen); % [m]
scmidthick = (scoutdiamid-(scoutdiamid^2-(screstmass*4/(pi*screstlen*dens)))^0.5)/2;


%   Top of outer framework
tofdiaside = 2.33; % [m]
tofdiamid = 2.29; % [m]
tofthick = 0.04; % [m]
toflen = (2*14.235)/10; % [m]
tofmass = masscalc(tofdiaside,tofthick,toflen)*2; % [kg]
tofrestmass = masscalc(2.33,0.04,6)+masscalc(2.29,0.019,19.35)+(1568)-tofmass; % [kg]
tofrestlen = (2*14.235)-(2*toflen); % [m]
tofmidthick = (tofdiamid-(tofdiamid^2-(tofrestmass*4/(pi*tofrestlen*dens)))^0.5)/2;

%   Bottom of outer framework
bofdia = 2.049; % [m]
bofthick = 0.025; % [m]
bofrestmass = masscalc(bofdia,bofthick,25.35)+2027; % [kg]
bofrestlen = (2*14.235); % [m]
bofmidthick = (bofdia-(bofdia^2-(bofrestmass*4/(pi*bofrestlen*dens)))^0.5)/2;

%   Radial bottom structure
rbdia = 1.75; % [m]
rbthick = 0.024; % [m]
rbrestmass = masscalc(rbdia,rbthick,50)+2740; % [kg]
rbrestlen = sqrt(55^2+7^2); % [m]
rbmidthick = (rbdia-(rbdia^2-(rbrestmass*4/(pi*rbrestlen*dens)))^0.5)/2;

%   Top framework
tfdiaside = 2.08; % [m]
tfdiamid = 2.05; % [m]
tfthick = 0.04; % [m]
tflen = 55/10; % [m]
tfmass = masscalc(tfdiaside,tfthick,tflen)*2; % [kg]
tfrestmass = masscalc(2.08,0.04,1.75+1.75)+masscalc(2.04,0.02,18.94+18.06)+masscalc(2.05,0.025,3+2+2)+masscalc(2.06,0.028,4)+(1351+225+225+225+1351+451)-tfmass; % [kg]
tfrestlen = 55-(2*tflen); % [m]
tfmidthick = (tfdiamid-(tfdiamid^2-(tfrestmass*4/(pi*tfrestlen*dens)))^0.5)/2;

%   Secondary column C11

scmidthickextra = scmidthick; % [m]

%   Output from function
%bctthick;
%ccmidthick;
%obtthick;
%mcmidthick;
%scmidthick;
%tofmidthick;
%bofmidthick;
%rbmidthick;
%tfmidthick;
%scmidthickextra

end