close all
clear all
clc

%%  RIGID OFFSHORE FISH-FARM CREATOR
%   Based on Ocean Farming/Global Maritime design
%   Code writes USFOS model file (model.fem)
%   P.T.B. & P.A.F., NTNU

%   MATERIAL DATA FOR THE NET IS MISSING
%   ALL THICKNESSES MUST BE CHECKED AND CHANGED
%   POINT MASSES MUST BE ADDED
%   DRAG COEFFICIENTS AND SUCH...

%%  Define overall cage geometry

radius = 55;        % radius [m]
Zside = -27;        % z-coordinate at bottom of side [m]
Zpontoon = -43;     % z-coordinate at bottom of pontoons [m]
height = 33;        % height outer columns [m]
heightcentre = 37;  % Height centre column

nSides = 12;        % number of sides
nCpontoons = 1;     % number of center pontoons
nSpontoons = 6;     % number of side pontoons


%  Define direction of incomming current (and waves) for assigning
%  currentblockage factors to correct members, 0 deg is in positive x-dir.

currdir = 270*pi/180;

%%  Define material and elemental geometry

%   Structural material
%   Steel
strucmat = 1;
strucemod = 210E9;      % Young's modulus [MPa]
strucpoiss = 0.3;       % Poisson's ratio
strucyield = 355E6;     % yield strength [MPa]
strucdens = 7850;       % steel density [kg/m3]

%   Net
strucmatnet = 2;
strucemodnet = 40E+9;
strucpoissnet = 0.3;
strucyieldnet = 355E7;
strucdensnet = 1025;
thermexpnet = 0.001;

%   Include thicknesses from separate function
[bctthick,ccmidthick,obtthick,mcmidthick,scmidthick,tofmidthick,bofmidthick,rbmidthick,tfmidthick,scmidthickextra] = thickness(strucdens);

%   ...geo is the geometric identifier
%   ...dia is the diameter of the element [m]
%   ...thick is the thickness of the element [m]

%   Bottom outer ring
botringgeo = 2;
botringendgeo = 3;
botringdia = 2.049;
botringthick = bofmidthick; % Smeared avg. thickness
botringendthick = bofmidthick; % Thickness ends (one element on each side)

%   Middle outer ring and diagonal supports
midsupgeo = 4;
midsupdiagendgeo = 5;
midsupdia = 1;
midsupthick = 0.015;
midsupdiagendthick = 0.03; % Thickness ends (one element on each side)

%   Top outer ring
topsupgeo = 6;
topsupendgeo = 7;
topsupdia = 2.29;
topsupenddia = 2.33;
topsupthick = tofmidthick; % Smeared avg. thickness
topsupendthick = 0.04; % Thickness ends (one element on each side)

%   Crossing wheelhouse supports
crosstopgeo = 8;
crosstopendgeo = 9;
crosstopdia = 2.05;
crosstopenddia = 2.08;
crosstopthick = tfmidthick; % Smeared avg. thickness
crosstopendthick = 0.04; % Thickness ends (one element on each side)

%   Bottom radial elements
botradgeo = 10;
botradendgeo = 11;
botraddia = 1.75;
botradthick = rbmidthick; % Smeared avg. thickness
botradendthick = rbmidthick; % Thickness lateral end (one element)

%   Outer verticals over pontoons
coloverpontgeo = 12;
coloverpontendgeo = 13;
coloverpontdia = 3.56;
coloverpontenddia = 3.58;
coloverpontthick = mcmidthick; % Smeared avg. thickness
coloverpontendthick = 0.04; % Thickness ends (one element on each side)

%   Intermediate verticals
intvertgeo = 14;
intvertendgeo = 15;
intvertdia = 2.80;
intvertenddia = 2.83;
intvertthick = scmidthick; % Smeared avg. thickness
intvertendthick = 0.04; % Thickness ends (one element on each side)

%   Center pontoon
centpontgeo = 16;
diacpontoon = 17;
centpontthick = bctthick; % Smeared avg. thickness
stepconegeo = 17;
centconethick = bctthick; % Same thickness as cylinder part of the centre pontoon
stepconedia = 8;
centconegeo = 18;
h1cpontoon = 7;         % heights starting from bottom and upwards [m]
h2cpontoon = 2;         % bottom braces center joint at this point
h3cpontoon = 3;

%   Outer pontoons
outpontgeo = 19;
dspontoon = 12;
outpontthick = double(obtthick); % Smeared avg. thickness of cone and bottom tank
outconegeo = 20;
h1spontoon = 7;         % heights starting from bottom and upwards [m]
h2spontoon = 6;
h3spontoon = 3;

%   Centre column
centcolgeo = 21;
centcolendgeo = 22;
centcoldia = 3.56;
centcolenddia = 3.58;
centcolthick = ccmidthick; % Smeared avg. thickness
centcolendthick = 0.04; % Thickness top element

% Movable bulkhead
movebulkgeo = 23;
movebulkwidth = 1.5;
movebulklengthtot = sqrt(55^2+7^2)+55;
movebulkweight = 299636;
movebulkthick = (movebulkwidth-(movebulkwidth^2-(movebulkweight/(movebulklengthtot*strucdens)))^0.5)/2;

% Fixed bulkhead
fixedbulkgeo = 24;
fixedbulkdia = 2.05;
fixedbulklengthtot = 55;
fixedbulkweight = 172001;
fixedbulkthick = (fixedbulkdia-(fixedbulkdia^2-(fixedbulkweight*4/(pi*fixedbulklengthtot*strucdens)))^0.5)/2;

%   Intermediate vertical column C11
intvertextrageo = 25;
intvertextrathick = scmidthickextra; % Smeared avg. thickness
intvertendthick = 0.04; % Thickness ends (one element on each side)

% Tanks (equipment masses)
verttankgeo = 26;
horiztankgeo = 27;

%   Net structure
netgeo = 28;
diathreads = 0.15;       % diameter of threads [m], 0.0025 correct value
thickthreads = 0.074;

%%  Mesh configuration

%   Splitting number must be even to assure symmetry, and equal or above 4
%   to create net connections, test model file by visual inspection before
%   analysis.

nSplitSide = 10;            % number of side splitting (vertical and horizontal)
nSplitBottom = 10;          % number of bottom braces/columns splitting
zStep = height/nSplitSide;  % vertical step size for side net

%   Base node angles
deltaangle = 2*pi/nSides;
theta = [];
for i = 1:nSides
    theta(i) = deltaangle*(i-1);
end

%   Bottom angle
thetaBottom = atan((h1spontoon+h2spontoon+h3spontoon-h1cpontoon-h2cpontoon)/radius);
%   Radius step on bottom net
rStep = (radius-(diacpontoon/2))/nSplitBottom;

%	Gathering all bottom nodes
NODE = [];
for k = 1:(nSplitBottom+1)
    %   base nodes
    Radius = (diacpontoon/2)+((k-1)*rStep);
    zCoord = (Zpontoon+h1cpontoon+h2cpontoon)+(Radius*tan(thetaBottom));
    Bnode = [];
    for i = 1:nSides
        Bnode(i,1) = -Radius*sin(theta(i));
        Bnode(i,2) = Radius*cos(theta(i));
        Bnode(i,3) = zCoord;
    end
    %   nodes in 4-dim matrix where 3rd dim is side number and 4th dim is
    %   radius number
    for i = 1:(nSides-1)
        for j = 1:nSplitSide
            NODE(j,1,i,k) = ((k-1)*nSplitSide*nSides)+((i-1)*nSplitSide)+j;
            xstep = (Bnode(i+1,1)-Bnode(i,1))/nSplitSide;
            ystep = (Bnode(i+1,2)-Bnode(i,2))/nSplitSide;
            NODE(j,2,i,k) = Bnode(i,1)+(j-1)*xstep;
            NODE(j,3,i,k) = Bnode(i,2)+(j-1)*ystep;
            NODE(j,4,i,k) = zCoord;
        end
    end
    %   12th side must be meshed separately
    for j = 1:nSplitSide
        NODE(j,1,nSides,k) = ((k-1)*nSplitSide*nSides)+((nSides-1)*nSplitSide)+j;
        xstep = (Bnode(1,1)-Bnode(nSides,1))/nSplitSide;
        ystep = (Bnode(1,2)-Bnode(nSides,2))/nSplitSide;
        NODE(j,2,nSides,k) = Bnode(nSides,1)+(j-1)*xstep;
        NODE(j,3,nSides,k) = Bnode(nSides,2)+(j-1)*ystep;
        NODE(j,4,nSides,k) = zCoord;
    end
end

%%  Write nodes to file

FID1 = fopen('model.fem','w');

%   Gathering all bottom nodes in 2-dim matrix
NODE2D = [];
for k = 1:(nSplitBottom+1)
    for i = 1:nSides
        for j = 1:nSplitSide
            NODE2D(((k-1)*nSplitSide*nSides)+((i-1)*nSplitSide)+j,1) = NODE(j,1,i,k);
            NODE2D(((k-1)*nSplitSide*nSides)+((i-1)*nSplitSide)+j,2) = NODE(j,2,i,k);
            NODE2D(((k-1)*nSplitSide*nSides)+((i-1)*nSplitSide)+j,3) = NODE(j,3,i,k);
            NODE2D(((k-1)*nSplitSide*nSides)+((i-1)*nSplitSide)+j,4) = NODE(j,4,i,k);
        end
    end
end

%   Writing all bottom nodes
nNodesBottom = length(NODE2D);
for i = 1:nNodesBottom
    fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',NODE2D(i,1),NODE2D(i,2),NODE2D(i,3),NODE2D(i,4));
end

%   Gathering all outer nodes in 2-dim matrix
NODE2DSIDE = [];
for i = 1:nSides
    for j = 1:nSplitSide
        NODE2DSIDE(((i-1)*nSplitSide)+j,1) = NODE(j,1,i,nSplitBottom+1);
        NODE2DSIDE(((i-1)*nSplitSide)+j,2) = NODE(j,2,i,nSplitBottom+1);
        NODE2DSIDE(((i-1)*nSplitSide)+j,3) = NODE(j,3,i,nSplitBottom+1);
        NODE2DSIDE(((i-1)*nSplitSide)+j,4) = NODE(j,4,i,nSplitBottom+1);
    end
end

%   Writing all side nodes
nNodesSide = length(NODE2DSIDE);
for j = 1:nSplitSide
    for i = 1:nNodesSide
        fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',NODE2DSIDE(i,1)+(j*nNodesSide),NODE2DSIDE(i,2),NODE2DSIDE(i,3),NODE2DSIDE(i,4)+(j*zStep));
    end
end
nodecount = NODE2DSIDE(i,1)+(j*nNodesSide);

%   Gathering structural nodes in matrices

%   Bottom
bottomstrucnodes = [];
j=1;
for i = 1:nSplitSide:nNodesBottom-nNodesSide
    bottomstrucnodes(j) = NODE2D(i,1);
    j=j+1;
end
for i = nNodesBottom-nNodesSide+1:nNodesBottom
    bottomstrucnodes(j) = NODE2D(i,1);
    j=j+1;
end

%   Side
NODE2DSIDEALL = [];
for j = 1:nSplitSide
    for i = 1:nNodesSide
        NODE2DSIDEALL(((j-1)*nNodesSide)+i) = NODE2DSIDE(i,1)+(j*nNodesSide);
    end
end

sidestrucnodes = [];
j=1;
for i = 1:nSplitSide:length(NODE2DSIDEALL)-nNodesSide
    sidestrucnodes(j) = NODE2DSIDEALL(i);
    j=j+1;
end
% Top ring
topringstrucnodes = [];
j=1;
for i = length(NODE2DSIDEALL)-nNodesSide+1:length(NODE2DSIDEALL)
    topringstrucnodes(j) = NODE2DSIDEALL(i);
    j=j+1;
end


%   Define side pontoons by nodes and write to file
sidepontMat = Bnode;
for i = 2:2:nSides
    sidepontMat(i,:) = 0;
end
sidepontMat(all(~sidepontMat,2),:) = [];
nodecount = nodecount+1;
for i = 1:length(sidepontMat)
    fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',nodecount,sidepontMat(i,1),sidepontMat(i,2),sidepontMat(i,3)-h3spontoon);
    nodecount = nodecount+1;
    fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',nodecount,sidepontMat(i,1),sidepontMat(i,2),sidepontMat(i,3)-h3spontoon-h2spontoon);
    nodecount = nodecount+1;
    fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',nodecount,sidepontMat(i,1),sidepontMat(i,2),sidepontMat(i,3)-h3spontoon-h2spontoon-h1spontoon);
    nodecount = nodecount+1;
end

%   Write center nodes (starting at bottom)

% Centre pontoon plus small column on top of centre pontoon
fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',nodecount,0,0,Zpontoon);
nodecount = nodecount+1;
fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',nodecount,0,0,Zpontoon+h1cpontoon);
nodecount = nodecount+1;
fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',nodecount,0,0,Zpontoon+h1cpontoon+h2cpontoon);
nodecount = nodecount+1;
%fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',nodecount,0,0,Zpontoon+h1cpontoon+h2cpontoon+h3cpontoon);
%nodecount = nodecount+1;
% Centre column
centrestrucnodes = [];
for i = 1:nSplitSide+1
   fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',nodecount,0,0,Zpontoon+h1cpontoon+h2cpontoon+h3cpontoon+(heightcentre/nSplitSide*(i-1)));
   centrestrucnodes(i) = nodecount;
   nodecount = nodecount+1;
end
topcentrenode = nodecount-1;

%fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',nodecount,0,0,Zpontoon+h1spontoon+h2spontoon+h3spontoon+(height-5)/2);
%nodecount = nodecount+1;
%fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',nodecount,0,0,Zpontoon+h1spontoon+h2spontoon+h3spontoon+height-5);
%nodecount = nodecount+1;
%fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',nodecount,0,0,Zpontoon+h1spontoon+h2spontoon+h3spontoon+height);
%topcentrenode = nodecount;
%nodecount = nodecount+1;

%centrestrucnodes = [];
%for i = 1:4
%    centrestrucnodes(i) = topcentrenode-(i-1);
%end

% Write crossing wheelhouse support nodes
nCrossings = 4; % Problems in code if this number is not 2,4,6 or 12
nExtraCrossings = 1; % The extra fixed bulkhead (changes in code required if this number is not 1)
nSplitCross = 10;
CrossStep = radius/nSplitCross;
thetaCross = [];
thetaCrossStep = 2*pi/nCrossings;
for i=1:nCrossings
    thetaCross(i) = (i-1)*thetaCrossStep;
end
thetaCross(nCrossings+nExtraCrossings) = theta(nSides); % The extra fixed bulkhead angle

CrossNodes = [];
for i = 1:nCrossings+nExtraCrossings
    for j = 1:nSplitCross-1
        fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',nodecount,-CrossStep*j*sin(thetaCross(i)),CrossStep*j*cos(thetaCross(i)),Zpontoon+h1spontoon+h2spontoon+h3spontoon+height);
        CrossNodes(j,i) = nodecount;
        nodecount = nodecount+1;
    end
end

crosstopstrucnodes = [];
crosstopdim = size(CrossNodes);
for i = 1:crosstopdim(2)
    for j = 1:crosstopdim(1)
        crosstopstrucnodes(((i-1)*crosstopdim(1))+j) = CrossNodes(j,i);
    end
end


%%  Write main element configuration

beamcount = 1;

%   Write center column (starting from the top)
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,topcentrenode,topcentrenode-1,strucmat,centcolendgeo);
beamcount = beamcount+1;
for i = 1:nSplitSide-1
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,centrestrucnodes(nSplitSide+1-i),centrestrucnodes(nSplitSide-i),strucmat,centcolgeo);
    beamcount = beamcount+1;
end
    
%fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,topcentrenode-1,topcentrenode-2,strucmat,centcolgeo);
%beamcount = beamcount+1;
%fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,topcentrenode-2,topcentrenode-3,strucmat,centcolgeo);
%beamcount = beamcount+1;

fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,topcentrenode-nSplitSide,topcentrenode-nSplitSide-1,strucmat,centconegeo);
beamcount = beamcount+1;
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,topcentrenode-nSplitSide-1,topcentrenode-nSplitSide-2,strucmat,stepconegeo);
beamcount = beamcount+1;
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,topcentrenode-nSplitSide-2,topcentrenode-nSplitSide-3,strucmat,centpontgeo);
centpontelement = beamcount;
beamcount = beamcount+1;

%   Write side pontoons
sidepontcolelem = [];
for i = 1:nSpontoons
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,(nNodesSide*nSplitBottom)+((i-1)*2*nSplitSide)+1,(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide+1))+((i-1)*3)+1,strucmat,coloverpontendgeo);
    sidepontcolelem(i) = beamcount;
    beamcount = beamcount+1;
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide+1))+((i-1)*3)+1,(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide+1))+((i-1)*3)+2,strucmat,outconegeo);
    beamcount = beamcount+1;
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide+1))+((i-1)*3)+2,(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide+1))+((i-1)*3)+3,strucmat,outpontgeo);
    beamcount = beamcount+1;
end

%   Write bottom radial beams

% Inner radial elements (first "round" of elements)
for i = 1:nSplitSide:nSides*nSplitSide
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,topcentrenode-nSplitSide-1,i,strucmat,botradgeo);
    beamcount = beamcount+1;
end
% The rest
for i = 1:nSplitBottom-1
    for j = 1:nSplitSide:nNodesSide
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((i-1)*nNodesSide)+j,(i*nNodesSide)+j,strucmat,botradgeo);
        beamcount = beamcount+1;
    end
end
% Lateral end elements
for j = 1:nSplitSide:nNodesSide
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((nSplitBottom-1)*nNodesSide)+j,(nSplitBottom*nNodesSide)+j,strucmat,botradendgeo);
    beamcount = beamcount+1;
end

% Outer vertical columns

% Columns over pontoons
k = 1;
vertcolpontelem = [];
for i = nSplitBottom+2:nSplitBottom+nSplitSide-1
    for j = 1:2*nSplitSide:nNodesSide
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((i-1)*nNodesSide)+j,(i*nNodesSide)+j,strucmat,coloverpontgeo);
        vertcolpontelem(k) = beamcount;
        beamcount = beamcount+1;
        k = k+1;
    end
end
% End elements
k = 1;
vertcolpontendelem = [];
for i = nSplitBottom+1:nSplitSide-1:nSplitBottom+nSplitSide
    for j = 1:2*nSplitSide:nNodesSide
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((i-1)*nNodesSide)+j,(i*nNodesSide)+j,strucmat,coloverpontendgeo);
        vertcolpontendelem(k) = beamcount;
        beamcount = beamcount+1;
        k = k+1;
    end
end

% Intermediate columns
k = 1;
vertcolintelem = [];
for i = nSplitBottom+2:nSplitBottom+nSplitSide-1
    for j = nSplitSide+1:2*nSplitSide:nNodesSide-nSplitSide
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((i-1)*nNodesSide)+j,(i*nNodesSide)+j,strucmat,intvertgeo);
        vertcolintelem(k) = beamcount;
        beamcount = beamcount+1;
        k = k+1;
    end
end
for i = nSplitBottom+2:nSplitBottom+nSplitSide-1
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((i-1)*nNodesSide)+nNodesSide+1-nSplitSide,(i*nNodesSide)+nNodesSide+1-nSplitSide,strucmat,intvertextrageo);
    vertcolintelem(k) = beamcount;
    beamcount = beamcount+1;
    k = k+1;
end

k = 1;
vertcolintendelem = [];
% End elements
for i = nSplitBottom+1:nSplitSide-1:nSplitBottom+nSplitSide
    for j = nSplitSide+1:2*nSplitSide:nNodesSide
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((i-1)*nNodesSide)+j,(i*nNodesSide)+j,strucmat,intvertendgeo);
        vertcolintendelem(k) = beamcount;
        beamcount = beamcount+1;
        k = k+1;
    end
end

%   Write outer circular rings
% Bottom
botringelem = [];
botringendelem = [];
k = 1;
l = 1;
for i = 1:nSides-1
    for j = 2:nSplitSide-1
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((i-1)*nSplitSide)+j+nNodesSide*nSplitBottom,((i-1)*nSplitSide)+j+nNodesSide*nSplitBottom+1,strucmat,botringgeo);
        botringelem(k) = beamcount;
        beamcount = beamcount+1;
        k = k+1;
    end
    for j = 1:nSplitSide-1:nSplitSide
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((i-1)*nSplitSide)+j+nNodesSide*nSplitBottom,((i-1)*nSplitSide)+j+nNodesSide*nSplitBottom+1,strucmat,botringendgeo);
    botringendelem(l) = beamcount;
    beamcount = beamcount+1;
    l = l+1;
    end
end
for j = 2:nSplitSide-1
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((nSides-1)*nSplitSide)+j+nNodesSide*nSplitBottom,((nSides-1)*nSplitSide)+j+nNodesSide*nSplitBottom+1,strucmat,botringgeo);
    botringelem(k) = beamcount;
    beamcount = beamcount+1;
    k = k+1;
end
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((nSides-1)*nSplitSide)+1+nNodesSide*nSplitBottom,((nSides-1)*nSplitSide)+1+nNodesSide*nSplitBottom+1,strucmat,botringendgeo);
botringendelem(l) = beamcount;
beamcount = beamcount+1;
l = l+1;
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,nNodesSide+nNodesSide*nSplitBottom,nNodesSide*nSplitBottom+1,strucmat,botringendgeo);
botringendelem(l) = beamcount;
beamcount = beamcount+1;

% Middle
for i = 1:nNodesSide-1
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,i+(nNodesSide*nSplitBottom)+(nSplitSide/2*nNodesSide),i+(nNodesSide*nSplitBottom)+(nSplitSide/2*nNodesSide)+1,strucmat,midsupgeo);
    beamcount = beamcount+1;
end
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,nNodesSide+(nNodesSide*nSplitBottom)+(nSplitSide/2*nNodesSide),(nNodesSide*nSplitBottom)+(nSplitSide/2*nNodesSide)+1,strucmat,midsupgeo);
beamcount = beamcount+1;

% Top
for i = 1:nSides-1
    for j = 2:nSplitSide-1
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((i-1)*nSplitSide)+j+(nNodesSide*nSplitBottom)+(nSplitSide*nNodesSide),((i-1)*nSplitSide)+j+(nNodesSide*nSplitBottom)+(nSplitSide*nNodesSide)+1,strucmat,topsupgeo);
        beamcount = beamcount+1;
    end
    for j = 1:nSplitSide-1:nSplitSide
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((i-1)*nSplitSide)+j+(nNodesSide*nSplitBottom)+(nSplitSide*nNodesSide),((i-1)*nSplitSide)+j+(nNodesSide*nSplitBottom)+(nSplitSide*nNodesSide)+1,strucmat,topsupendgeo);
        beamcount = beamcount+1;
    end
end
for j = 2:nSplitSide-1
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((nSides-1)*nSplitSide)+j+(nNodesSide*nSplitBottom)+(nSplitSide*nNodesSide),((nSides-1)*nSplitSide)+j+(nNodesSide*nSplitBottom)+(nSplitSide*nNodesSide)+1,strucmat,topsupgeo);
    beamcount = beamcount+1;
end
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,((nSides-1)*nSplitSide)+1+(nNodesSide*nSplitBottom)+(nSplitSide*nNodesSide),((nSides-1)*nSplitSide)+1+(nNodesSide*nSplitBottom)+(nSplitSide*nNodesSide)+1,strucmat,topsupendgeo);
beamcount = beamcount+1;
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,nNodesSide+(nNodesSide*nSplitBottom)+(nSplitSide*nNodesSide),(nNodesSide*nSplitBottom)+(nSplitSide*nNodesSide)+1,strucmat,topsupendgeo);
beamcount = beamcount+1;

%   Write crossing wheelhouse supports

for i = 1:nCrossings
    sizeCross = size(CrossNodes);
    for j = 1:sizeCross(1,1)-1
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,CrossNodes(j,i),CrossNodes(j,i)+1,strucmat,crosstopgeo);
        beamcount = beamcount+1;
    end
    
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,topcentrenode,CrossNodes(1,i),strucmat,crosstopendgeo);
    beamcount = beamcount+1;
  
    endCrossNodes = (nNodesSide*nSplitBottom)+(nSplitSide*nNodesSide)+1:nNodesSide/nCrossings:(nNodesSide*nSplitBottom)+(nSplitSide*nNodesSide)+nNodesSide;
    
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,CrossNodes(sizeCross(1,1),i),endCrossNodes(i),strucmat,crosstopendgeo);
    beamcount = beamcount+1;
end
% Writing the extra fixed bulkhead crossing
for j = 1:sizeCross(1,1)-1
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,CrossNodes(j,sizeCross(1,2)),CrossNodes(j,sizeCross(1,2))+1,strucmat,fixedbulkgeo);
    beamcount = beamcount+1;
end
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,topcentrenode,CrossNodes(1,sizeCross(1,2)),strucmat,fixedbulkgeo);
beamcount = beamcount+1;
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,CrossNodes(sizeCross(1,1),sizeCross(1,2)),endCrossNodes(nCrossings)+(2*nNodesSide/nSides),strucmat,fixedbulkgeo);
beamcount = beamcount+1;

%   Writing movable bulkhead
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,topcentrenode,endCrossNodes(nCrossings)-(4*nNodesSide/nSides),strucmat,movebulkgeo);
topmovebulkelem = beamcount;
beamcount = beamcount+1;
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,topcentrenode-nSplitSide,nNodesSide*nSplitBottom+nNodesSide+1+(5*nSplitSide),strucmat,movebulkgeo);
bottommovebulkelem = beamcount;
beamcount = beamcount+1;

%   Write diagonals

%   Downwards
for i = 1:2*nSplitSide:nNodesSide-nSplitSide
    for j = 2:nSplitSide-1
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,i+(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide-(j-1)))+(j-1),i+(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide-j))+j,strucmat,midsupgeo);
        beamcount = beamcount+1;
    end
    for j = 1:nSplitSide-1:nSplitSide
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,i+(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide-(j-1)))+(j-1),i+(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide-j))+j,strucmat,midsupdiagendgeo);
    beamcount = beamcount+1;
    end
end
%   Upwards
for i = 1+nSplitSide:2*nSplitSide:nNodesSide-nSplitSide
    for j = 2:nSplitSide-1
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,i+(nNodesSide*nSplitBottom)+(nNodesSide*(j-1))+(j-1),i+(nNodesSide*nSplitBottom)+(nNodesSide*j)+j,strucmat,midsupgeo);
        beamcount = beamcount+1;
    end
    for j = 1:nSplitSide-1:nSplitSide
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,i+(nNodesSide*nSplitBottom)+(nNodesSide*(j-1))+(j-1),i+(nNodesSide*nSplitBottom)+(nNodesSide*j)+j,strucmat,midsupdiagendgeo);
    beamcount = beamcount+1;
    end
end
for j = 2:nSplitSide-1
    fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,(nNodesSide-(nSplitSide-1))+(nNodesSide*nSplitBottom)+(nNodesSide*(j-1))+(j-1),(nNodesSide-(nSplitSide-1))+(nNodesSide*nSplitBottom)+(nNodesSide*j)+j,strucmat,midsupgeo);
    beamcount = beamcount+1;
end
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,(nNodesSide-(nSplitSide-1))+(nNodesSide*nSplitBottom)+(nNodesSide*(1-1))+(1-1),(nNodesSide-(nSplitSide-1))+(nNodesSide*nSplitBottom)+(nNodesSide*1)+1,strucmat,midsupdiagendgeo);
beamcount = beamcount+1;
fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcount,(nNodesSide-(nSplitSide-1))+(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide-1))+(nSplitSide-1),1+(nNodesSide*nSplitBottom)+(nSplitSide*nNodesSide),strucmat,midsupdiagendgeo);
beamcount = beamcount+1;

%%  Write net configuration

netcount = beamcount+mod(-beamcount,1000);

%   Bottom net

%   Radial direction
BottomRadialNetElem = [];
for i = 1:nSides
    for j = 2:nSplitSide
        for k = 1:nSplitBottom
            fprintf(FID1,'BEAM %i %i %i %i %i %i\n',netcount,((i-1)*nSplitSide)+j+((k-1)*nNodesSide),((i-1)*nSplitSide)+j+(k*nNodesSide),strucmatnet,netgeo,i);
            BottomRadialNetElem(k+((j-2)*nSplitBottom),i) = netcount;
            netcount = netcount+1;
        end
    end
end
%   Circumferantial direction
BottomCircumNetElem = [];
for i = 1:nSides-1
    for j = 1:nSplitBottom
        for k = 1:nSplitSide
            fprintf(FID1,'BEAM %i %i %i %i %i %i\n',netcount,((i-1)*nSplitSide)+k+((j-1)*nNodesSide),((i-1)*nSplitSide)+k+1+((j-1)*nNodesSide),strucmatnet,netgeo,i);
            BottomCircumNetElem(k+((j-1)*nSplitSide),i) = netcount;
            netcount = netcount+1;
        end
    end
end
for j = 1:nSplitBottom
    for k = 1:nSplitSide-1
        fprintf(FID1,'BEAM %i %i %i %i %i %i\n',netcount,((nSides-1)*nSplitSide)+k+((j-1)*nNodesSide),((nSides-1)*nSplitSide)+k+1+((j-1)*nNodesSide),strucmatnet,netgeo,nSides);
        BottomCircumNetElem(k+((j-1)*(nSplitSide-1)),nSides) = netcount;
        netcount = netcount+1;
    end
end
for j = 1:nSplitBottom
    fprintf(FID1,'BEAM %i %i %i %i %i %i\n',netcount,((nSides-1)*nSplitSide)+nSplitSide+((j-1)*nNodesSide),1+((j-1)*nNodesSide),strucmatnet,netgeo,nSides);
    BottomCircumNetElem(j+(nSplitBottom*(nSplitSide-1)),nSides) = netcount;
    netcount = netcount+1;
end

%   Side net

%   Vertical direction
SideVerticalNetElem = [];
for i = 1:nSides
    for j = 2:nSplitSide
        for k = 1:nSplitSide
            fprintf(FID1,'BEAM %i %i %i %i %i %i\n',netcount,(nNodesSide*nSplitBottom)+((i-1)*nSplitSide)+j+((k-1)*nNodesSide),(nNodesSide*nSplitBottom)+((i-1)*nSplitSide)+j+(k*nNodesSide),strucmatnet,netgeo,i+nSides);
            SideVerticalNetElem(k+((j-2)*nSplitSide),i) = netcount;
            netcount = netcount+1;
        end
    end
end
SideHorizontalNetElem = [];
%   Horizontal direction
for i = 1:nSides-1
    for j = 2:nSplitSide
        for k = 1:nSplitSide
            fprintf(FID1,'BEAM %i %i %i %i %i %i\n',netcount,(nNodesSide*nSplitBottom)+((i-1)*nSplitSide)+k+((j-1)*nNodesSide),(nNodesSide*nSplitBottom)+((i-1)*nSplitSide)+k+1+((j-1)*nNodesSide),strucmatnet,netgeo,i+nSides);
            SideHorizontalNetElem(k+((j-2)*nSplitSide),i) = netcount;
            netcount = netcount+1;
        end
    end
end
for j = 2:nSplitSide
    for k = 1:nSplitSide-1
        fprintf(FID1,'BEAM %i %i %i %i %i %i\n',netcount,(nNodesSide*nSplitBottom)+((nSides-1)*nSplitSide)+k+((j-1)*nNodesSide),(nNodesSide*nSplitBottom)+((nSides-1)*nSplitSide)+k+1+((j-1)*nNodesSide),strucmatnet,netgeo,nSides+nSides);
        SideHorizontalNetElem(k+((j-2)*(nSplitSide-1)),nSides) = netcount;
        netcount = netcount+1;
    end
end
for j = 2:nSplitSide
    fprintf(FID1,'BEAM %i %i %i %i %i %i\n',netcount,(nNodesSide*nSplitBottom)+((nSides-1)*nSplitSide)+nSplitSide+((j-1)*nNodesSide),(nNodesSide*nSplitBottom)+1+((j-1)*nNodesSide),strucmatnet,netgeo,nSides+nSides);
    SideHorizontalNetElem((j-1)+((nSplitSide-1)*(nSplitSide-1)),nSides) = netcount;
    netcount = netcount+1;
end

%%  Write material data and elemental geometry

fprintf(FID1,'MISOIEP %i %.2e %.2f %.2e %.2e\n',strucmat,strucemod,strucpoiss,strucyield,strucdens);
fprintf(FID1,'MISOIEP %i %.2e %.2f %.2e %.2e %.3f\n',strucmatnet,strucemodnet,strucpoissnet,strucyieldnet,strucdensnet,thermexpnet);

fprintf(FID1,'PIPE %i %.3f %.3f\n',botringgeo,botringdia,botringthick);         % Bottom outer ring
fprintf(FID1,'PIPE %i %.3f %.3f\n',botringendgeo,botringdia,botringendthick);   % Bottom outer ring end elements
fprintf(FID1,'PIPE %i %.3f %.3f\n',midsupgeo,midsupdia,midsupthick);            % Middle outer ring and diagonal supports
fprintf(FID1,'PIPE %i %.3f %.3f\n',midsupdiagendgeo,midsupdia,midsupdiagendthick); % Diagonal supports end elements
fprintf(FID1,'PIPE %i %.3f %.3f\n',topsupgeo,topsupdia,topsupthick);            % Top outer ring
fprintf(FID1,'PIPE %i %.3f %.3f\n',topsupendgeo,topsupenddia,topsupendthick);      % Top outer ring end elements
fprintf(FID1,'PIPE %i %.3f %.3f\n',crosstopgeo,crosstopdia,crosstopthick);      % Crossing wheelhouse supports
fprintf(FID1,'PIPE %i %.3f %.3f\n',crosstopendgeo,crosstopenddia,crosstopendthick); % Crossing wheelhouse supports end elements
fprintf(FID1,'PIPE %i %.3f %.3f\n',botradgeo,botraddia,botradthick);            % Bottom radial elements
fprintf(FID1,'PIPE %i %.3f %.3f\n',botradendgeo,botraddia,botradendthick);      % Bottom radial lateral end element
fprintf(FID1,'PIPE %i %.3f %.3f\n',coloverpontgeo,coloverpontdia,coloverpontthick); % Outer columns over pontoons
fprintf(FID1,'PIPE %i %.3f %.3f\n',coloverpontendgeo,coloverpontenddia,coloverpontendthick); % Outer columns over pontoons end elements
fprintf(FID1,'PIPE %i %.3f %.3f\n',intvertgeo,intvertdia,intvertthick);         % Intermediate vertical columns
fprintf(FID1,'PIPE %i %.3f %.3f\n',intvertendgeo,intvertenddia,intvertendthick);   % Intermediate vertical columns end elements
fprintf(FID1,'PIPE %i %.3f %.3f\n',outpontgeo,dspontoon,outpontthick);          % Outer pontoon, bottom tank
fprintf(FID1,'PIPE %i %.3f %.3f %i %i %.3f\n',outconegeo,coloverpontenddia,outpontthick,1,1,dspontoon); % Outer pontoon, cone
fprintf(FID1,'PIPE %i %.3f %.3f\n',centpontgeo,diacpontoon,centpontthick);      % Centre pontoon, bottom tank
fprintf(FID1,'PIPE %i %.3f %.3f\n',stepconegeo,stepconedia,centconethick);      % Centre pontoon, intermediate tank
fprintf(FID1,'PIPE %i %.3f %.3f %i %i %.3f\n',centconegeo,centcoldia,centconethick,1,1,stepconedia); % Centre pontoon, cone
fprintf(FID1,'PIPE %i %.3f %.3f\n',centcolgeo,centcoldia,centcolthick);         % Centre column
fprintf(FID1,'PIPE %i %.3f %.3f\n',centcolendgeo,centcolenddia,centcolendthick);   % Centre column top element
fprintf(FID1,'BOX %i %.3f %.3f %.3f %.3f %.3f\n',movebulkgeo,movebulkwidth,movebulkthick,movebulkthick,movebulkthick,movebulkwidth);   % Movable bulkhead
fprintf(FID1,'PIPE %i %.3f %.3f\n',fixedbulkgeo,fixedbulkdia,fixedbulkthick);   % Fixed bulkhead
fprintf(FID1,'PIPE %i %.3f %.3f\n',intvertextrageo,intvertdia,intvertextrathick);         % Intermediate vertical column C11

fprintf(FID1,'PIPE %i %.3f %.3f\n',netgeo,diathreads,thickthreads);             % Net

fprintf(FID1,'Geometry %i TankVert 1\n',verttankgeo);                           % Vertical tank (equipment)
fprintf(FID1,'Geometry %i TankHoriz 1\n',horiztankgeo);                         % Horizontal tank (equipment)

%%  Writing groups for net

groupcount = 1;

%   Bottom net
dummy = size(BottomRadialNetElem);
for i = 1:nSides
    fprintf(FID1,'GROUPDEF %i Element\n',groupcount);
    groupcount = groupcount+1;
    for j = 1:floor(dummy(1,1)/4)
    fprintf(FID1,'%i %i %i %i\n',BottomRadialNetElem((j-1)*4+1,i),BottomRadialNetElem((j-1)*4+2,i),BottomRadialNetElem((j-1)*4+3,i),BottomRadialNetElem((j-1)*4+4,i));
    end
    for k = (floor(dummy(1,1)/4)*4)+1:dummy(1,1)
        fprintf(FID1,'%i\n',BottomRadialNetElem(k,i));
    end
end
dummy = size(BottomCircumNetElem);
for i = 1:nSides
    fprintf(FID1,'GROUPDEF %i Element\n',groupcount);
    groupcount = groupcount+1;
    for j = 1:floor(dummy(1,1)/4)
    fprintf(FID1,'%i %i %i %i\n',BottomCircumNetElem((j-1)*4+1,i),BottomCircumNetElem((j-1)*4+2,i),BottomCircumNetElem((j-1)*4+3,i),BottomCircumNetElem((j-1)*4+4,i));
    end
    for k = (floor(dummy(1,1)/4)*4)+1:dummy(1,1)
        fprintf(FID1,'%i\n',BottomCircumNetElem(k,i));
    end
end
bottomgroupcount = groupcount-1;

%   Side Net
dummy = size(SideVerticalNetElem);
for i = 1:nSides
    fprintf(FID1,'GROUPDEF %i Element\n',groupcount);
    groupcount = groupcount+1;
    for j = 1:floor(dummy(1,1)/4)
    fprintf(FID1,'%i %i %i %i\n',SideVerticalNetElem((j-1)*4+1,i),SideVerticalNetElem((j-1)*4+2,i),SideVerticalNetElem((j-1)*4+3,i),SideVerticalNetElem((j-1)*4+4,i));
    end
    for k = (floor(dummy(1,1)/4)*4)+1:dummy(1,1)
        fprintf(FID1,'%i\n',SideVerticalNetElem(k,i));
    end
end
dummy = size(SideHorizontalNetElem);
for i = 1:nSides
    fprintf(FID1,'GROUPDEF %i Element\n',groupcount);
    groupcount = groupcount+1;
    for j = 1:floor(dummy(1,1)/4)
    fprintf(FID1,'%i %i %i %i\n',SideHorizontalNetElem((j-1)*4+1,i),SideHorizontalNetElem((j-1)*4+2,i),SideHorizontalNetElem((j-1)*4+3,i),SideHorizontalNetElem((j-1)*4+4,i));
    end
    for k = (floor(dummy(1,1)/4)*4)+1:dummy(1,1)
        fprintf(FID1,'%i\n',SideHorizontalNetElem(k,i));
    end
end
sidegroupcount = groupcount-1;

%------Gathering net-groups-------------

% Entire bottom net
fprintf(FID1,'GROUPDEF %i Group\n',groupcount);
for i=1:bottomgroupcount
    fprintf(FID1,'%i\n',i);
end
entirebottomnetgroup = groupcount;
groupcount = groupcount+1;

% Entire side net
fprintf(FID1,'GROUPDEF %i Group\n',groupcount);
for i=bottomgroupcount+1:sidegroupcount
    fprintf(FID1,'%i\n',i);
end
entiresidenetgroup = groupcount;
groupcount = groupcount+1;

% Entire net
fprintf(FID1,'GROUPDEF %i Group %i %i\n',groupcount,entirebottomnetgroup,entiresidenetgroup);
entirenetgroup = groupcount;
groupcount = groupcount+1;

%   Pontoons
fprintf(FID1,'GROUPDEF %i Geom %i %i\n',groupcount,outpontgeo,outconegeo);
groupcount = groupcount+1;
fprintf(FID1,'GROUPDEF %i Geom %i\n',groupcount,centpontgeo);
centpontgroup = groupcount;
groupcount = groupcount+1;
fprintf(FID1,'GROUPDEF %i Elem %i %i %i %i %i %i\n',groupcount,sidepontcolelem);
fprintf(FID1,'FLOODED Group %i %i\n',groupcount-1,groupcount-2);
groupcount = groupcount+1;

% fprintf(FID1,'IntFluid %.1f TimeDep %i Element %i\n',1024,105,centpontelement);

% ------ Making the movable bulkhead non-structural -----------
fprintf(FID1,'NONSTRU Geom %i\n',movebulkgeo);

%-------Temperature field, net------

dummy1 = size(BottomRadialNetElem);
dummy2 = size(BottomCircumNetElem);
dummy3 = size(SideVerticalNetElem);
dummy4 = size(SideHorizontalNetElem);

fprintf(FID1,'ELEMTEMP 10 1 -1.0 0.0 0.0\n');
% Bottom net
for i = 1:dummy1(1,2)
    for j = 1:floor(dummy1(1,1)/4)
        fprintf(FID1,'%i %i %i %i\n',BottomRadialNetElem((j-1)*4+1,i),BottomRadialNetElem((j-1)*4+2,i),BottomRadialNetElem((j-1)*4+3,i),BottomRadialNetElem((j-1)*4+4,i));
    end
    for k = (floor(dummy1(1,1)/4)*4)+1:dummy1(1,1)
        fprintf(FID1,'%i\n',BottomRadialNetElem(k,i));
    end
end
for i = 1:dummy2(1,2)
    for j = 1:floor(dummy2(1,1)/4)
        fprintf(FID1,'%i %i %i %i\n',BottomCircumNetElem((j-1)*4+1,i),BottomCircumNetElem((j-1)*4+2,i),BottomCircumNetElem((j-1)*4+3,i),BottomCircumNetElem((j-1)*4+4,i));
    end
    for k = (floor(dummy2(1,1)/4)*4)+1:dummy2(1,1)
        fprintf(FID1,'%i\n',BottomCircumNetElem(k,i));
    end
end
% Side net
for i = 1:dummy3(1,2)
    for j = 1:floor(dummy3(1,1)/4)
        fprintf(FID1,'%i %i %i %i\n',SideVerticalNetElem((j-1)*4+1,i),SideVerticalNetElem((j-1)*4+2,i),SideVerticalNetElem((j-1)*4+3,i),SideVerticalNetElem((j-1)*4+4,i));
    end
    for k = (floor(dummy3(1,1)/4)*4)+1:dummy3(1,1)
        fprintf(FID1,'%i\n',SideVerticalNetElem(k,i));
    end
end
for i = 1:dummy4(1,2)
    for j = 1:floor(dummy4(1,1)/4)
        fprintf(FID1,'%i %i %i %i\n',SideHorizontalNetElem((j-1)*4+1,i),SideHorizontalNetElem((j-1)*4+2,i),SideHorizontalNetElem((j-1)*4+3,i),SideHorizontalNetElem((j-1)*4+4,i));
    end
    for k = (floor(dummy4(1,1)/4)*4)+1:dummy4(1,1)
        fprintf(FID1,'%i\n',SideHorizontalNetElem(k,i));
    end
end


%%  Defining local z-axis of net

unitveccount = 1;
thetaNside = [];
for i = 1:nSides-1
    thetaNside(i) = theta(i)+((theta(i+1)-theta(i))/2);
end
thetaNside(nSides) = theta(nSides)+(((2*pi)-theta(nSides))/2);

%   Bottom net
for i = 1:nSides
    fprintf(FID1,'UNITVEC %i %.3f %.3f %.3f\n',unitveccount,-sin(thetaBottom)*sin(thetaNside(i)),sin(thetaBottom)*cos(thetaNside(i)),-cos(thetaBottom));
    unitveccount = unitveccount+1;
end

%   Side net
for i = 1:nSides
    fprintf(FID1,'UNITVEC %i %.3f %.3f 0.0\n',unitveccount,-sin(thetaNside(i)),cos(thetaNside(i)));
    unitveccount = unitveccount+1;
end

%% Node and element masses

fishfoodmass = 600000;              % Apply at top centre node
marinegrowthmass = 50000;           % Apply at all side columns nodes + bottom
icemass = 109000;                   % Apply at all side columns nodes
maindeckmass = 350496;              % Apply at top centre node
equiptmentmassaqua = 151141;        % Apply at all top nodes + centre column + top ring
equiptmentmassmarine = 140163;      % Apply at all side column nodes
walkwaymass = 150870;               % Apply at all top crossing nodes + centre column + top ring
foundationmass = 129961;            % Apply at top crossing nodes + top ring
platesdeckmass = 72138;             % Apply at all side column nodes + centre column
bracketmass = 100000;               % Apply at all side column nodes + bottom
anodemass = 15000;                  % Apply at all side column nodes
paintweldscorrosionmass = 329856;   % Apply at all structural nodes
bulkheadmass = 172001+195706;       % Apply at all top crossing nodes + top ring + all side columns

oiltankmass = 18600;                % At top crossings, specified node
watertankmass = 22000;              % At top crossings, specified node
ensiletankmass = 50000;             % At top crossings, specified node
fueloilmass = 3000;                 % At top crossings, specified node
extramass = 0;                      % Applied to get correct draught

sidecolumnmass = (icemass+equiptmentmassmarine+anodemass)/length(sidestrucnodes);   % To be places at all side column nodes
centremass = fishfoodmass+maindeckmass;                                             % To be places at top node
sidecolumnbottommass = (marinegrowthmass+bracketmass)/(length(bottomstrucnodes)+length(sidestrucnodes)); % To be placed at all side column and bottom nodes
topmass = foundationmass/(length(crosstopstrucnodes)+length(topringstrucnodes));    % To be places at all top crossing and top ring nodes
topcentrecolumnmass = (equiptmentmassaqua+walkwaymass)/(length(crosstopstrucnodes)+length(centrestrucnodes)+length(topringstrucnodes)); % To be places at all top crossing, top ring and centre column nodes
columnmass = bracketmass/(length(sidestrucnodes)+length(centrestrucnodes));         % To be placed at all column nodes
topcrossringsidecolumnmass = bulkheadmass/(length(sidestrucnodes)+length(topringstrucnodes)+length(crosstopstrucnodes));    % To be places at all top crossing, top ring and side columns
allstrucnodesmass = paintweldscorrosionmass/(length(bottomstrucnodes)+length(sidestrucnodes)+length(topringstrucnodes)+length(centrestrucnodes)+length(crosstopstrucnodes)); % To be placed at all structural nodes

totnodemass = icemass+equiptmentmassmarine+anodemass+fishfoodmass+maindeckmass+marinegrowthmass+bracketmass+foundationmass+equiptmentmassaqua+walkwaymass+bracketmass+paintweldscorrosionmass+oiltankmass+watertankmass+ensiletankmass+fueloilmass+bulkheadmass;

% Equipment material
decktankmat = 100;
oiltankmat = 110;
watertankmat = 120;
ensiletankmat = 130;

% Centre node masses and other tanks
fprintf(FID1,'Material %i Equip %.1f\n',decktankmat,centremass+fueloilmass);
fprintf(FID1,'Material %i Equip %.1f\n',oiltankmat,oiltankmass); 
fprintf(FID1,'Material %i Equip %.1f\n',watertankmat,watertankmass); 
fprintf(FID1,'Material %i Equip %.1f\n',ensiletankmat,ensiletankmass); 

% Fish food tank + centre node mass
fprintf(FID1,'Equip_1N %i %i %i %i\n',netcount,topcentrenode,decktankmat,verttankgeo);
netcount = netcount+1;
% Oil tank
fprintf(FID1,'Equip_1N %i %i %i %i\n',netcount,CrossNodes(2,1),oiltankmat,verttankgeo);
netcount = netcount+1;
% Water tank
fprintf(FID1,'Equip_1N %i %i %i %i\n',netcount,CrossNodes(1,2),watertankmat,verttankgeo);
netcount = netcount+1;
fprintf(FID1,'Equip_1N %i %i %i %i\n',netcount,CrossNodes(2,4),ensiletankmat,verttankgeo);
netcount = netcount+1;

% Masses at side columns
for i = 1:length(sidestrucnodes)
    fprintf(FID1,'NODEMASS %i %.1f\n',sidestrucnodes(i),sidecolumnmass);
    fprintf(FID1,'NODEMASS %i %.1f\n',sidestrucnodes(i),sidecolumnbottommass);
    fprintf(FID1,'NODEMASS %i %.1f\n',sidestrucnodes(i),columnmass);
    fprintf(FID1,'NODEMASS %i %.1f\n',sidestrucnodes(i),allstrucnodesmass);
    fprintf(FID1,'NODEMASS %i %.1f\n',sidestrucnodes(i),topcrossringsidecolumnmass);
end

% Masses at top crossings
for i = 1:length(crosstopstrucnodes)
    fprintf(FID1,'NODEMASS %i %.1f\n',crosstopstrucnodes(i),topmass);
    fprintf(FID1,'NODEMASS %i %.1f\n',crosstopstrucnodes(i),topcentrecolumnmass);
    fprintf(FID1,'NODEMASS %i %.1f\n',crosstopstrucnodes(i),allstrucnodesmass);
    fprintf(FID1,'NODEMASS %i %.1f\n',crosstopstrucnodes(i),topcrossringsidecolumnmass);
end

% Masses at top ring
for i = 1:length(topringstrucnodes)
    fprintf(FID1,'NODEMASS %i %.1f\n',topringstrucnodes(i),topmass);
    fprintf(FID1,'NODEMASS %i %.1f\n',topringstrucnodes(i),topcentrecolumnmass);
    fprintf(FID1,'NODEMASS %i %.1f\n',topringstrucnodes(i),allstrucnodesmass);
    fprintf(FID1,'NODEMASS %i %.1f\n',topringstrucnodes(i),topcrossringsidecolumnmass);
end

% Masses as centre column
for i = 1:length(centrestrucnodes)
    fprintf(FID1,'NODEMASS %i %.1f\n',centrestrucnodes(i),topcentrecolumnmass);
    fprintf(FID1,'NODEMASS %i %.1f\n',centrestrucnodes(i),columnmass);
    fprintf(FID1,'NODEMASS %i %.1f\n',centrestrucnodes(i),allstrucnodesmass);
end

% Masses at bottom
for i = 1:length(bottomstrucnodes)
    fprintf(FID1,'NODEMASS %i %.1f\n',bottomstrucnodes(i),sidecolumnbottommass);
    fprintf(FID1,'NODEMASS %i %.1f\n',bottomstrucnodes(i),allstrucnodesmass);
end


%% Forces/moments applied to find natural periods

% Water plane stiffness
Atot = pi/4*(coloverpontdia^2+intvertdia^2)*6;
C33 = Atot*9.81*1025;

loadcount = 50;

% HEAVE
% Force to find natural period in heave
heaveload = 2*C33/nSides; %(will give a vertical displacement of two meter)
% Side mass (applied at top of all outer columns)
%for i = (nNodesSide*(nSplitBottom+nSplitSide))+1:nSplitSide:(nNodesSide*(nSplitBottom+nSplitSide))+nNodesSide
%    fprintf(FID1,'NODELOAD %i %i 0 0 %.1f\n',loadcount,i,-heaveload);
%end

% ROLL
rolload = C33/10;
rollmoment = C33*15;

outercolumntopnodes = (nNodesSide*(nSplitBottom+nSplitSide))+1:nSplitSide:(nNodesSide*(nSplitBottom+nSplitSide))+nNodesSide;

%for i=1:3
%    fprintf(FID1,'NODELOAD %i %i 0 0 %.1f\n',loadcount,outercolumntopnodes(i),-rolload);
%    fprintf(FID1,'NODELOAD %i %i 0 0 %.1f\n',loadcount,outercolumntopnodes(i+4),rolload);
%end

%for i=1:2
%    fprintf(FID1,'NODELOAD %i %i 0 0 %.1f\n',loadcount,outercolumntopnodes(nSides-(i-1)),-rolload);
%    fprintf(FID1,'NODELOAD %i %i 0 0 %.1f\n',loadcount,outercolumntopnodes(i+7),rolload); 
%end

%fprintf(FID1,'NODELOAD %i %i 0 0 0 %.1f 0 0\n',loadcount,topcentrenode-(nSplitSide/2),rollmoment);

% PITCH

%fprintf(FID1,'NODELOAD %i %i 0 0 0 0 %.1f 0\n',loadcount,topcentrenode-(nSplitSide/2),rollmoment);

% SWAY

swayload = C33/(nSplitSide/2+1);

%for i = 1:nSplitSide/2+1
%    fprintf(FID1,'NODELOAD %i %i 0 %.1f 0 0 0 0\n',loadcount,((nSplitBottom*nNodesSide)+1)+((i-1)*nNodesSide),swayload);
%end

% SURGE

%for i = 1:nSplitSide/2+1
%    fprintf(FID1,'NODELOAD %i %i %.1f 0 0 0 0 0\n',loadcount,((nSplitBottom*nNodesSide)+(3*nSplitSide)+1)+((i-1)*nNodesSide),swayload);
%end

% YAW

%fprintf(FID1,'NODELOAD %i %i 0 0 0 0 0 %.1f\n',loadcount,topcentrenode-2,2*rollmoment);

loadcount = loadcount+1;

%%  Current blockage
%   Direction is defined at the top of the script.

deltanet = 30*pi/180;           % Angle between net sides
startangle = (270+15)*pi/180;   % Net group 1 has normal direction 285 deg
nNetGroups = 4*nSides;          % Number of net groups
currblock = 0.9;

% The net

% All net groups must be assisiated with a direction (normal to the net, outwards)
netgroupdir = [];

for i = 1:4
    for j = 1:nSides
        netgroupdir((i-1)*nSides+j,1) = (i-1)*nSides+j;
        if j<=3
            netgroupdir((i-1)*nSides+j,2) = startangle+((j-1)*deltanet);
        else
            netgroupdir((i-1)*nSides+j,2) = startangle+((j-1)*deltanet)-(2*pi);
        end
    end
end

% Scanning through netgroupdir and assigning current blockage factor to
% correct groups

if (currdir >= pi/2) && (currdir <= 3*pi/2)     % Between 90 and 270 deg
    for i = 1:nNetGroups
     if netgroupdir(i,2) < currdir-(pi/2)-0.01
            fprintf(FID1,'HYDROPAR CurrBlock %.2f Group %i\n',currblock,netgroupdir(i,1));
     elseif netgroupdir(i,2) > currdir+(pi/2)+0.01
           fprintf(FID1,'HYDROPAR CurrBlock %.2f Group %i\n',currblock,netgroupdir(i,1));
     end
    end
end
if (currdir < pi/2) && (currdir >= 0)           % < 90 deg
    for i = 1:nNetGroups
        if (netgroupdir(i,2) > currdir+(pi/2)) && (netgroupdir(i,2) < ((2*pi)-((pi/2)-currdir)))
            fprintf(FID1,'HYDROPAR CurrBlock %.2f Group %i\n',currblock,netgroupdir(i,1));
        end
    end
end
if (currdir > 3*pi/2) && (currdir <= 2*pi)      % > 270 deg
    for i = 1:nNetGroups
        if (netgroupdir(i,2) < currdir-(pi/2)) && (netgroupdir(i,2) > (currdir-(3*pi/2)))
            fprintf(FID1,'HYDROPAR CurrBlock %.2f Group %i\n',currblock,netgroupdir(i,1));
        end
    end
end

% Centre column
fprintf(FID1,'HYDROPAR CurrBlock %.2f Geo %i\n',currblock,centcolgeo);
fprintf(FID1,'HYDROPAR CurrBlock %.2f Geo %i\n',currblock,centcolendgeo);
fprintf(FID1,'HYDROPAR CurrBlock %.2f Geo %i\n',currblock,centconegeo);

% Vertical columns
deltavertcol = 2*pi/6;
startanglepont = 3*pi/2;                        % Start angle, columns over pontoons
startangleint = (3*pi/2)+(deltavertcol/2);      % Start angle, intermediate columns
vertcoldir = [];
% All elements must be assisiated with a direction (normal to the net, outwards)

% Columns over pontoons
k = 1;
dircolpont = startanglepont;
for i = 1:length(vertcolpontelem)
    vertcoldir(k,1) = vertcolpontelem(i);
    vertcoldir(k,2) = dircolpont;
    dircolpont = dircolpont + deltavertcol;
    if dircolpont >= 2*pi-0.01
        dircolpont = deltavertcol/2;
    end
    k = k+1;
end
dircolpont = startanglepont;
for i = 1:length(vertcolpontendelem)
    vertcoldir(k,1) = vertcolpontendelem(i);
    vertcoldir(k,2) = dircolpont;
    dircolpont = dircolpont + deltavertcol;
    if dircolpont >= 2*pi-0.01
        dircolpont = deltavertcol/2;
    end
    k = k+1;
end

dircolint = startangleint;
for i = 1:length(vertcolintelem)-(nSplitSide-2)
    vertcoldir(k,1) = vertcolintelem(i);
    vertcoldir(k,2) = dircolint;
    dircolint = dircolint + deltavertcol;
    if dircolint >= 2*pi-0.01
        dircolint = 0;
    end
    if (dircolint >= startangleint-(deltavertcol+0.01)) && (dircolint <= startangleint-0.01)
        dircolint = startangleint;
    end
    k = k+1;
end
for i = length(vertcolintelem)-(nSplitSide-2)+1:length(vertcolintelem)
    vertcoldir(k,1) = vertcolintelem(i);
    vertcoldir(k,2) = startangle-deltavertcol;
    k = k+1;
end
dircolint = startangleint;
for i = 1:length(vertcolintendelem)
    vertcoldir(k,1) = vertcolintendelem(i);
    vertcoldir(k,2) = dircolint;
    dircolint = dircolint + deltavertcol;
    if dircolint >= 2*pi-0.01
        dircolint = 0;
    end
    k = k+1;
end

nColElem = k-1;
% Scanning through vertcoldir and assigning current blockage factor to
% correct elements

if (currdir >= pi/2) && (currdir <= 3*pi/2)     % Between 90 and 270 deg
    for i = 1:nColElem
     if vertcoldir(i,2) < currdir-(pi/2)-0.01
            fprintf(FID1,'HYDROPAR CurrBlock %.2f Elem %i\n',currblock,vertcoldir(i,1));
     elseif vertcoldir(i,2) > currdir+(pi/2)+0.01
           fprintf(FID1,'HYDROPAR CurrBlock %.2f Elem %i\n',currblock,vertcoldir(i,1));
     end
    end
end
if (currdir < pi/2) && (currdir >= 0)           % < 90 deg
    for i = 1:nColElem
        if (vertcoldir(i,2) > currdir+(pi/2)) && (vertcoldir(i,2) < ((2*pi)-((pi/2)-currdir)))
            fprintf(FID1,'HYDROPAR CurrBlock %.2f Elem %i\n',currblock,vertcoldir(i,1));
        end
    end
end
if (currdir > 3*pi/2) && (currdir <= 2*pi)      % > 270 deg
    for i = 1:nColElem
        if (vertcoldir(i,2) < currdir-(pi/2)) && (vertcoldir(i,2) > (currdir-(3*pi/2)))
            fprintf(FID1,'HYDROPAR CurrBlock %.2f Elem %i\n',currblock,vertcoldir(i,1));
        end
    end
end

% Bottom ring

deltabottomelem = 2*pi/nSides;
startanglebottom = (3*pi/2)+(deltabottomelem/2);
bottomdir = [];

k = 1;
dirbottom = startanglebottom;
for i = 1:nSides-1
    for j = 1:nSplitSide-2
        bottomdir(k,1) = botringelem(((i-1)*(nSplitSide-2))+j);
        bottomdir(k,2) = dirbottom;
        k = k+1;
    end
    dirbottom = dirbottom+deltabottomelem;
    if dirbottom >= 2*pi-0.01
        dirbottom = deltabottomelem/2;
    end
    if (dirbottom >= startanglebottom-(deltabottomelem+0.01)) && (dirbottom <= startanglebottom-0.01)
        dirbottom = startanglebottom;
    end
end
for i = length(botringelem)-(nSplitSide-2)+1:length(botringelem)
    bottomdir(k,1) = botringelem(i);
    bottomdir(k,2) = startanglebottom-deltabottomelem;
    k = k+1;
end

dirbottom = startanglebottom;
for i = 1:nSides-1
    for j = 1:2
        bottomdir(k,1) = botringendelem(((i-1)*2)+j);
        bottomdir(k,2) = dirbottom;
        k = k+1;
    end
        dirbottom = dirbottom+deltabottomelem;
    if dirbottom >= 2*pi-0.01
        dirbottom = deltabottomelem/2;
    end
    if (dirbottom >= startanglebottom-(deltabottomelem+0.01)) && (dirbottom <= startanglebottom-0.01)
        dirbottom = startanglebottom;
    end
end
for i = length(botringendelem)-2+1:length(botringendelem)
    bottomdir(k,1) = botringendelem(i);
    bottomdir(k,2) = startanglebottom-deltabottomelem;
    k = k+1;
end

nBotElem = k-1;
% Scanning through vertcoldir and assigning current blockage factor to
% correct elements

if (currdir >= pi/2) && (currdir <= 3*pi/2)     % Between 90 and 270 deg
    for i = 1:nBotElem
     if bottomdir(i,2) < currdir-(pi/2)-0.01
            fprintf(FID1,'HYDROPAR CurrBlock %.2f Elem %i\n',currblock,bottomdir(i,1));
     elseif bottomdir(i,2) > currdir+(pi/2)+0.01
           fprintf(FID1,'HYDROPAR CurrBlock %.2f Elem %i\n',currblock,bottomdir(i,1));
     end
    end
end
if (currdir < pi/2) && (currdir >= 0)           % < 90 deg
    for i = 1:nBotElem
        if (bottomdir(i,2) > currdir+(pi/2)) && (bottomdir(i,2) < ((2*pi)-((pi/2)-currdir)))
            fprintf(FID1,'HYDROPAR CurrBlock %.2f Elem %i\n',currblock,bottomdir(i,1));
        end
    end
end
if (currdir > 3*pi/2) && (currdir <= 2*pi)      % > 270 deg
    for i = 1:nBotElem
        if (bottomdir(i,2) < currdir-(pi/2)) && (bottomdir(i,2) > (currdir-(3*pi/2)))
            fprintf(FID1,'HYDROPAR CurrBlock %.2f Elem %i\n',currblock,bottomdir(i,1));
        end
    end
end

%%  Mooring line properties

g = 9.81;           % acceleration of gravity [m/s2]
rhowater = 1025;    % density of water [kg/m3]
depth = 150;        % water depth [m]
phi = 49.1*pi/180;  % top angle at mooring point on cage

%   Top tension [N]
T = 20*g*10^3;
Ty = T*cos(phi);
Tz = T*sin(phi);

%   Mooring line is part chain (steel), part fibre (polyester)

%   Chain
Lchain = 1000;
Dchain = sqrt(2)*0.088;
EAchain = 6.94*10^4*g*10^3;
wChain = 147;               % weight in water [kg/m]
MBLchain = 718.8*g*10^3;
Achain = pi/4*Dchain^2;
yieldChain = MBLchain/Achain;
Echain = EAchain/Achain;
rhoChain = (wChain+(Achain*rhowater))/Achain;

geoChain = 30;  % geometry ID
matChain = 30;  % material ID

%   Fibre
Lfibre = 100;
Dfibre = 0.16;
EAfibre = 2.40*10^4*g*10^3;
wFibre = 4;                 % weight in water [kg/m]
MBLfibre = 828*g*10^3;
Afibre = pi/4*Dfibre^2;
yieldFibre = MBLfibre/Afibre;
Efibre = EAfibre/Afibre;
rhoFibre = (wFibre+(Afibre*rhowater))/Afibre;

geoFibre = 40;  % geometry ID
matFibre = 40;  % material ID

Ltot = Lchain+Lfibre;   % total length
Lstep = 5;              % step size
nBeams = Ltot/Lstep;    % number of splits
nl = 8;                 % number of lines
nN = nBeams+1;          % number of nodes

%   Number of springtoground must be set manually, check output from
%   mooring line stretch-up.
nS2G = 181;

%%  Read mooringline coordinates
%   Single line coordinates taken from file res_ufo.fem

FID2 = fopen('res_ufo.fem','r');
%   Skip first 5 rows
for i = 1:5
    fgetl(FID2);
end
READNODE = textscan(FID2,'%s %d %f %f %f %d %d %d %d %d %d',nN);
fclose(FID2);

%%  Copy mooring line, translate and rotate

%   Node coordinates

NODEnumber = READNODE{2};
xNODEcord = READNODE{3};
yNODEcord = READNODE{4};
zNODEcord = READNODE{5};

%   Figure for documentation

figure()
plot(yNODEcord,zNODEcord)
xlabel('Distance from anchor [m]')
ylabel('z [m]')
title('Mooring line profile')
xlim([700 1100])
ylim([-150 10])
grid on

figure()
plot(yNODEcord(1:201),zNODEcord(1:201),yNODEcord(201:end),zNODEcord(201:end),'r');
legend('Chain','Fibre');
xlabel('Distance from anchor [m]')
ylabel('z [m]')
title('Mooring line profile')
xlim([700 1100])
ylim([-150 10])
grid on

%   Line angles
thetaLine = [];
anglestep = 2*pi/nl;
startAngle = 22.5*pi/180;
for i = 1:nl
    thetaLine(i) = (i-1)*anglestep+startAngle;
end

%   Line 1 goes in positive y-direction and negative x-direction with an
%   angle of 22.5 degrees, where 0 degrees is in positive y-direction.

Lhor = yNODEcord(nN);   % horizontal length of line

%   Coordinates in new system
xNODEcordNEW = [];
yNODEcordNEW = [];
zNODEcordNEW = [];

%   Translating mooring line in z-direction to get to correct depth of
%   mooring line top.
Ztrans =(Bnode(1,3)-zNODEcord(nN))-h3spontoon;

%   Base mooring line
for i = 1:nN
    xNODEcordNEW(i) = 0;
    yNODEcordNEW(i) = Lhor-yNODEcord(i);
    zNODEcordNEW(i) = zNODEcord(i)+Ztrans;
end

%   Rotating mooring lines to their respective angles
xNODErotation=[];
yNODErotation=[];
zNODErotation=[];
for i = 1:nl
    for j = 1:nN
        xNODErotation(j,i) = -yNODEcordNEW(j)*sin(thetaLine(i));
        yNODErotation(j,i) = yNODEcordNEW(j)*cos(thetaLine(i));
        zNODErotation(j,i) = zNODEcordNEW(j);
    end
end

%   Translating mooring lines to their respective poontoons
xNODEmooring = [];
yNODEmooring = [];
zNODEmooring = [];
for j = 1:nN
    xNODEmooring(j,1) = xNODErotation(j,1)+(sidepontMat(2,1)-xNODErotation(nN,1));
    yNODEmooring(j,1) = yNODErotation(j,1)+(sidepontMat(2,2)-yNODErotation(nN,1));
    zNODEmooring(j,1) = zNODErotation(j,1);
     
    xNODEmooring(j,2) = xNODErotation(j,2)+(sidepontMat(2,1)-xNODErotation(nN,2));
    yNODEmooring(j,2) = yNODErotation(j,2)+(sidepontMat(2,2)-yNODErotation(nN,2));
    zNODEmooring(j,2) = zNODErotation(j,2);
     
    xNODEmooring(j,3) = xNODErotation(j,3)+(sidepontMat(3,1)-xNODErotation(nN,3));
    yNODEmooring(j,3) = yNODErotation(j,3)+(sidepontMat(3,2)-yNODErotation(nN,3));
    zNODEmooring(j,3) = zNODErotation(j,3);
     
    xNODEmooring(j,4) = xNODErotation(j,4)+(sidepontMat(3,1)-xNODErotation(nN,4));
    yNODEmooring(j,4) = yNODErotation(j,4)+(sidepontMat(3,2)-yNODErotation(nN,4));
    zNODEmooring(j,4) = zNODErotation(j,4);
     
    xNODEmooring(j,5) = xNODErotation(j,5)+(sidepontMat(5,1)-xNODErotation(nN,5));
    yNODEmooring(j,5) = yNODErotation(j,5)+(sidepontMat(5,2)-yNODErotation(nN,5));
    zNODEmooring(j,5) = zNODErotation(j,5);
     
    xNODEmooring(j,6) = xNODErotation(j,6)+(sidepontMat(5,1)-xNODErotation(nN,6));
    yNODEmooring(j,6) = yNODErotation(j,6)+(sidepontMat(5,2)-yNODErotation(nN,6));
    zNODEmooring(j,6) = zNODErotation(j,6);
     
    xNODEmooring(j,7) = xNODErotation(j,7)+(sidepontMat(6,1)-xNODErotation(nN,7));
    yNODEmooring(j,7) = yNODErotation(j,7)+(sidepontMat(6,2)-yNODErotation(nN,7));
    zNODEmooring(j,7) = zNODErotation(j,7);
     
    xNODEmooring(j,8) = xNODErotation(j,8)+(sidepontMat(6,1)-xNODErotation(nN,8));
    yNODEmooring(j,8) = yNODErotation(j,8)+(sidepontMat(6,2)-yNODErotation(nN,8));
    zNODEmooring(j,8) = zNODErotation(j,8);
end

%   Making coordinates to each line
Line = [];
for i = 1:nl
    for j = 1:nN
        Line(j,1,i) = ((i-1)*nN)+NODEnumber(j);
        Line(j,2,i) = xNODEmooring(j,i);
        Line(j,3,i) = yNODEmooring(j,i);
        Line(j,4,i) = zNODEmooring(j,i);
    end
end

%   Mooringline matrices on the following form, ID X Y Z
Line1 = Line(:,:,1);
Line2 = Line(:,:,2);
Line3 = Line(:,:,3);
Line4 = Line(:,:,4);
Line5 = Line(:,:,5);
Line6 = Line(:,:,6);
Line7 = Line(:,:,7);
Line8 = Line(:,:,8);

%   Figures for documentation

figure()
plot(Line1(:,2),Line1(:,3),Line2(:,2),Line2(:,3),Line3(:,2),Line3(:,3),Line4(:,2),Line4(:,3),Line5(:,2),Line5(:,3),Line6(:,2),Line6(:,3),Line7(:,2),Line7(:,3),Line8(:,2),Line8(:,3))
legend('Line 1','Line 2','Line 3','Line 4','Line 5','Line 6','Line 7','Line 8')
xlabel('x [m]')
ylabel('y [m]')
title('Mooring spread')

figure()
plot(Line1(:,3),Line1(:,4))
xlabel('y [m]')
ylabel('z [m]')
title('Mooring line profile')

figure()
plot3(Line1(:,2),Line1(:,3),Line1(:,4),Line2(:,2),Line2(:,3),Line2(:,4),Line3(:,2),Line3(:,3),Line3(:,4),Line4(:,2),Line4(:,3),Line4(:,4),Line5(:,2),Line5(:,3),Line5(:,4),Line6(:,2),Line6(:,3),Line6(:,4),Line7(:,2),Line7(:,3),Line7(:,4),Line8(:,2),Line8(:,3),Line8(:,4))
legend('Line 1','Line 2','Line 3','Line 4','Line 5','Line 6','Line 7','Line 8')
xlabel('x [m]')
ylabel('y [m]')
zlabel('z [m]')
title('Mooring spread')

%%  Writing mooring lines

%   Nodes
for j = 1:nl
    fprintf(FID1,'NODE %i %.3f %.3f %.3f 1 1 1 1 1 1\n',Line(1,:,j));
    for i = 2:nN-1
        fprintf(FID1,'NODE %i %.3f %.3f %.3f\n',Line(i,1,j),Line(i,2,j),Line(i,3,j),Line(i,4,j));
    end
end

%   Beams
nChain = Lchain/Lstep;
nFibre = Lfibre/Lstep;
beamcounter = netcount+mod(-netcount,1000);
for j = 1:nl
    % chain
    for i = 1:nChain
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcounter,Line(i,1,j),Line(i+1,1,j),matChain,geoChain);
        beamcounter = beamcounter+1;
    end
    % fiber
    for i = 1+nChain:nBeams-1
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcounter,Line(i,1,j),Line(i+1,1,j),matFibre,geoFibre);
        beamcounter = beamcounter+1;
    end
    if j <= 2
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcounter,Line(nBeams,1,j),(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide+1))+((2-1)*3)+1,matFibre,geoFibre);
        beamcounter = beamcounter+1;
    elseif j>2 && j<=4
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcounter,Line(nBeams,1,j),(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide+1))+((3-1)*3)+1,matFibre,geoFibre);
        beamcounter = beamcounter+1;
    elseif j>4 && j<=6
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcounter,Line(nBeams,1,j),(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide+1))+((5-1)*3)+1,matFibre,geoFibre);
        beamcounter = beamcounter+1;
    else
        fprintf(FID1,'BEAM %i %i %i %i %i\n',beamcounter,Line(nBeams,1,j),(nNodesSide*nSplitBottom)+(nNodesSide*(nSplitSide+1))+((6-1)*3)+1,matFibre,geoFibre);
        beamcounter = beamcounter+1;
    end
end

%   Spring to ground
materialS2G = 50;
S2Gcount = beamcounter+mod(-beamcounter,1000);
for j = 1:nl
    for i = 1:nS2G
        fprintf(FID1,'SPRNG2GR %i %i %i\n',S2Gcount,Line(i,1,j),materialS2G);
        S2Gcount = S2Gcount+1;
    end
end

%% Spring to ground for mooring line elements above sea bottom

seabottom = Line(1,4,1);

% Springs defined for all chain elements
% Spring material
for i=nS2G+1:nChain
    fprintf(FID1,'HYPELAST %i\n',materialS2G+i-nS2G);
    fprintf(FID1,'%.2e %.2f\n',-1E6,seabottom-Line(i,4,1)-3);
    fprintf(FID1,'%.2e %.2f\n',-2E5,seabottom-Line(i,4,1)-2);
    fprintf(FID1,'%.2e %.2f\n',-1E5,seabottom-Line(i,4,1)-1);
    fprintf(FID1,'%i %.2f\n',0,seabottom-Line(i,4,1));
    fprintf(FID1,'%i %.2f\n',0,0);
    fprintf(FID1,'%i %.2f\n',0,10);
    fprintf(FID1,'%i %.2f\n',0,20);
    fprintf(FID1,'MREF %i 0 0 %i 0 0 0\n',nChain+i-nS2G,materialS2G+i-nS2G);
end

% Writing springs
for i=1:nl
    for j=nS2G+1:nChain
        fprintf(FID1,'SPRNG2GR %i %i %i\n',S2Gcount,Line(j,1,i),nChain+j-nS2G);
        S2Gcount = S2Gcount+1;
    end
end
        
    



%%  Material, geometric, and loading data

fprintf(FID1,'MISOIEP %i %.2e %.2f %.2e %.2e\n', matChain,Echain,0.3,yieldChain,rhoChain);
fprintf(FID1,'MISOIEP %i %.2e %.2f %.2e %.2e\n', matFibre,Efibre,0.3,yieldFibre,rhoFibre);
fprintf(FID1,'MATERIAL %i Fric Comp %.2f %.2e %i %i\n',materialS2G,0.7,1E5,12,3);

fprintf(FID1,'PIPE %i %.3f %.3f\n', geoChain,Dchain,Dchain/2-0.001);
fprintf(FID1,'PIPE %i %.3f %.3f\n', geoFibre,Dfibre,Dfibre/2-0.001);

fprintf(FID1,'GRAVITY 1 0 0 -9.81\n');

% Groups by material
fprintf(FID1,'GROUPDEF %i Mat %i\n',groupcount,strucmat);
structuregroup = groupcount;
groupcount = groupcount+1;
fprintf(FID1,'GROUPDEF %i Mat %i\n',groupcount,matChain);
chaingroup = groupcount;
groupcount = groupcount+1;
fprintf(FID1,'GROUPDEF %i Mat %i\n',groupcount,matFibre);
fibregroup = groupcount;
groupcount = groupcount+1;

%%  Close file at end of creator

fclose(FID1);